/**
 *@description {收费项设置}
 */
var wFeeItem = {
	hiddenDelFixed: true,
	hiddenDelMeter: true,
	isInited: false,
	/**
	 *@description {初始化：绑定事件}
	 */
	addEventListener: function() {

		//显示删除固定收费项按钮
		var showDelFixed = document.getElementById('showDelFixed');
		if (showDelFixed != null) {
			showDelFixed.addEventListener('tap', function() {
				if (wFeeItem.hiddenDelFixed) {
					setItemsVisibility('#liItemsFixed .delItem', '');
				} else {
					setItemsVisibility('#liItemsFixed .delItem', 'none');
				}
				wFeeItem.hiddenDelFixed = !wFeeItem.hiddenDelFixed;
			});
			//删除固定收费项
			mui('#liItemsFixed').on('tap', '.delItem', function() {
				
				//Android 4.0.4; zh-cn; Lenovo K860i Build/IMM76D
				var liItemsFixed=document.getElementById("liItemsFixed");
				liItemsFixed.removeChild(this.parentElement);
			});
		}

		//显示删除仪表收费项按钮
		var showDelMeter = document.getElementById('showDelMeter');
		if (showDelMeter != null) {
			showDelMeter.addEventListener('tap', function() {
				if (wFeeItem.hiddenDelMeter) {
					setItemsVisibility('#liItemsMeter .delItem', '');
				} else {
					setItemsVisibility('#liItemsMeter .delItem', 'none');
				}
				wFeeItem.hiddenDelMeter = !wFeeItem.hiddenDelMeter;
			});

			//删除仪表收费项
			mui('#liItemsMeter').on('tap', '.delItem', function() {
				var name = (this.previousSibling.previousSibling.previousSibling.innerText);

				//Android 4.0.4; zh-cn; Lenovo K860i Build/IMM76D
				var liItemsMeter=document.getElementById("liItemsMeter");
				
				//清除分割线
				liItemsMeter.removeChild(this.parentElement.nextSibling.nextSibling.nextSibling);
				//清除最低用量
				liItemsMeter.removeChild(this.parentElement.nextSibling.nextSibling);
				//清除最近表值
				liItemsMeter.removeChild(this.parentElement.nextSibling);
				//清除删除按钮所在的div
				liItemsMeter.removeChild(this.parentElement);
			});
		}

		//显示删除押金项按钮
		var showDelDeposit = document.getElementById('showDelDeposit');
		if (showDelDeposit != null) {
			showDelDeposit.addEventListener('tap', function() {
				if (wFeeItem.hiddenDelFixed) {
					setItemsVisibility('#liItemsDeposit .delItem', '');
				} else {
					setItemsVisibility('#liItemsDeposit .delItem', 'none');
				}
				wFeeItem.hiddenDelFixed = !wFeeItem.hiddenDelFixed;
			});

			//删除押金收费项
			mui('#liItemsDeposit').on('tap', '.delItem', function() {
				var liItems=document.getElementById("liItemsDeposit");
				liItems.removeChild(this.parentElement);
			});
		}
	},
	/**
	 *@description {初始化 绑定事件并加载默认收费项}
	 */
	init: function() {
		wFeeItem.loadDefaultFixedFees();
		wFeeItem.loadDefaultMeterFees();
		wFeeItem.loadEmptyMeterFees('#metersCustom>ul');
		wFeeItem.addEventListener();
		wFeeItem.setRentValue();
		wFeeItem.isInited = true;
	},
	/**
	 *@description {初始化 绑定事件并加载收费项}
	 */
	init: function(feeItems) {

		//加载设置中默认的收费项
		wFeeItem.loadDefaultFixedFees();
		wFeeItem.loadDefaultMeterFees();

		//加载自定义仪表费可选择的收费项
		wFeeItem.loadEmptyMeterFees('#metersCustom>ul');
		//加载空的押金收费项
		wFeeItem.loadEmptyDepositFees();

		wFeeItem.clear();
		//绑定收费项
		mui.each(feeItems, function(i, f) {
			switch (f.FeeType) {
				case 'Rent':
					wFeeItem.setRentValue(f.Fee, f.ID);
					break;
				case 'Normal':
					wFeeItem.appendFixedRow(f.FeeName, f.Fee, f.ID);
					break;
				case 'Water':
					wFeeItem.appendMeterRow(f.FeeName, f.FeeType, '吨', f.MeterPrice, f.LowestConsume, f.CurrMeterNum, f.ID);
					break;
				case 'Power':
					wFeeItem.appendMeterRow(f.FeeName, f.FeeType, '度', f.MeterPrice, f.LowestConsume, f.CurrMeterNum, f.ID);
					break;
				case 'Gas':
					wFeeItem.appendMeterRow(f.FeeName, f.FeeType, '方', f.MeterPrice, f.LowestConsume, f.CurrMeterNum, f.ID);
					break;
				case 'HotWater':
					wFeeItem.appendMeterRow(f.FeeName, f.FeeType, '吨', f.MeterPrice, f.LowestConsume, f.CurrMeterNum, f.ID);
					break;
				case 'Deposit':
				case 'RentDeposit':
					wFeeItem.appendDepositRow(f.FeeName, f.FeeType, f.Fee, f.ID);
					break;
			}
		});
		wFeeItem.isInited = true;
		wFeeItem.addEventListener();
	},
	/**
	 *@description {设置租金值}
	 * @param {fee} 金额
	 * @param {id} ID
	 */
	setRentValue: function(fee, id) {
		if (fee == '' || isNaN(fee)) {
			fee = 0;
		}
		var inputRent = document.getElementById("Rent");
		if (inputRent != null) {
			inputRent.value = fee;
			inputRent.setAttribute('FeeID', id);
		}
	},
	/**
	 *@description {添加固定收费项}
	 * @param {name} 名称
	 * @param {type} 类别 Normal,Rent
	 * @param {fee} 金额
	 * @param {id} ID
	 */
	appendFixedRow: function(name, fee, id) {
		if (id > -1)
			setItemsVisibility('#fixeds', 'none');
		else if (wFeeItem.isInited) {
			id = -1;
			mui('#fixeds').popover('toggle');
		}
		var liItems = document.getElementById("liItemsFixed");
		var divRow = document.createElement('div');
		divRow.setAttribute('ID', id);
		divRow.className = 'mui-input-row';
		divRow.innerHTML = '<input name="FeeName" FeeType="Normal" type="text" class="label unit" placeholder="输入名称" value="' + name + '" />&nbsp;<input name="Fee"  type="number" placeholder="金额" style="border: none; border-bottom: solid 1px #c8c7cc;" class="mui-input-clear unit" value="' + fee + '" ><label class="unit-s">元</label><span class="iconfont icon-jian delItem" style="display:none;"></span>';
		liItems.appendChild(divRow);

		wFeeItem.getData();
	},
	/**
	 *@description {添加押金收费项}
	 */
	appendDepositRow: function(name, type, fee, id) {

		var liItems = document.getElementById("liItemsDeposit");
		if (liItems == null)
			return;
		if (type == undefined || type == '') {
			type = 'Deposit';
		}
		if (id > -1)
			setItemsVisibility('#deposits', 'none');
		else if (wFeeItem.isInited)
			mui('#deposits').popover('toggle');

		var divRow = document.createElement('div');
		divRow.setAttribute('ID', id);
		divRow.className = 'mui-input-row';
		divRow.innerHTML = '<input name="FeeName" FeeType="' + type + '" type="text" class="label unit" placeholder="输入名称" value="' + name + '" />&nbsp;<input name="Fee"  type="number" placeholder="金额" style="border: none; border-bottom: solid 1px #c8c7cc;" class="mui-input-clear unit" value="' + fee + '" ><label class="unit-s">元</label><span class="iconfont icon-jian delItem" style="display:none;"></span>';
		liItems.appendChild(divRow);

		wFeeItem.getData();
	},
	/**
	 *@description {添加仪表收费项}
	 * @param {name} 名称
	 * @param {type} 类别 Water,PowerGas,HotWater
	 * @param {unit} 计量单位
	 * @param {price} 价格
	 * @param {lowest} 最低用量
	 * @param {qty} 当前表值
	 * @param {id} ID
	 */
	appendMeterRow: function(name, type, unit, price, lowest, qty, id) {

		if (id <= 0 && wFeeItem.isInited) { //如果是点击自定义后的，就不执行toggle 
			var cache = getJSONCache(default_meterfees);
			if (id < -1 || cache == null) {
				//添加已有水电表
				mui('#meters').popover('toggle');
			} else {
				//添加自定义水电表
				mui('#metersCustom').popover('toggle');
			}
			id = -1;
		}
		var liItems = document.getElementById("liItemsMeter");
		var divRow1 = document.createElement('div');
		divRow1.setAttribute('ID', id);
		divRow1.setAttribute('FeeType', type);
		divRow1.className = 'mui-input-row';
		divRow1.innerHTML = '<input value="' + name + '" class="label unit" />&nbsp<input name="MeterPrice"  type="number" placeholder="价格" style="border: none; border-bottom: solid 1px #c8c7cc; padding-left:5px;" class="mui-input-clear unit" value="' + price + '"><label class="unit-s">元/' + unit + '</label><span class="iconfont icon-jian delItem" style="display:none; margin-top:10px;"></span>';
		var divRow2 = document.createElement('div');
		divRow2.className = 'mui-input-row';
		divRow2.innerHTML = '<label>最低用量</label><input name="LowestConsume"  type="number" style="border:none; border-bottom: solid 1px #c8c7cc;" class="mui-input-clear unit" value="' + lowest + '"><label class="unit-s">' + unit + '</label>';
		var divRow3 = document.createElement('div');
		divRow3.className = 'mui-input-row  currMeterNum';
		divRow3.innerHTML = '<label>最近表值</label><input name="CurrMeterNum"  type="number" style="border: none; border-bottom: solid 1px #c8c7cc;" class="mui-input-clear unit" value="' + qty + '"><label class="unit-s">' + unit + '</label>';
		liItems.appendChild(divRow1);
		liItems.appendChild(divRow2);
		liItems.appendChild(divRow3);
		var diver = document.createElement('div');
		diver.className = 'divider'
		liItems.appendChild(diver);

		wFeeItem.getData();
	},
	/**
	 *@description {获取收费项JSON格式数据}
	 */
	getData: function() {

		//var formStr = serialize(document.getElementById("form"));
		var itemsStr = wFeeItem.getRent() + ',';

		//拼固定收费项JSON
		var itemsFixed = document.querySelectorAll('#liItemsFixed>div');
		var len1 = itemsFixed.length;
		var itemFixedsStr = '';
		for (var i = 0; i < len1; i++) {
			var id = itemsFixed[i].getAttribute('ID');
			id = id == 'undefined' ? -1 : id;
			var feeName = itemsFixed[i].children[0].value;
			var feeType = itemsFixed[i].children[0].getAttribute('FeeType');
			var fee = itemsFixed[i].children[1].value;
			if (fee == '' || isNaN(fee)) {
				continue;
			}
			if (feeType == '' || feeType == null) {
				feeType = 'Normal';
			}
			if (feeName != '' && itemFixedsStr.indexOf('"' + feeName + '"') > 0) {
				mui.toast('收费项名称 "' + feeName + '" 重复了，修改下名称吧');
				return false;
			}

			itemFixedsStr += '{"ID":' + id + ',"FeeType":"' + feeType + '","FeeName":"' + feeName + '","Fee":"' + fee + '"},';
		}
		itemsStr += itemFixedsStr;

		//拼押金收费项JSON
		var itemsDeposit = document.querySelectorAll('#liItemsDeposit>div');
		if (itemsDeposit != null) {

			var itemDepositsStr = '';
			var len3 = itemsDeposit.length;

			for (var i = 0; i < len3; i++) {
				var id = itemsDeposit[i].getAttribute('ID');
				id = id == 'undefined' ? -1 : id;
				var feeName = itemsDeposit[i].children[0].value;
				var feeType = itemsDeposit[i].children[0].getAttribute('FeeType');
				var fee = itemsDeposit[i].children[1].value;

				if (fee == '' || isNaN(fee)) {
					//console.log('请输入有效的金额')
					continue;
				}
				if (feeType == '' || feeType == null) {
					feeType = 'Deposit';
				}
				if (feeName != '' && itemDepositsStr.indexOf('"' + feeName + '"') > 0) {
					mui.toast('名称 "' + feeName + '" 重复了，修改下名称吧');
					return false;
				}

				itemDepositsStr += '{"ID":' + id + ',"FeeType":"' + feeType + '","FeeName":"' + feeName + '","Fee":"' + fee + '"},';
			}
			itemsStr += itemDepositsStr;
		}

		//拼仪表收费项JSON
		var itemsMeter = document.querySelectorAll('#liItemsMeter>div');
		var len2 = itemsMeter.length;
		var itemMetersStr = '';
		for (var i = 0; i < len2; i++) {
			var id = itemsMeter[i].getAttribute('ID');
			id = id == 'undefined' ? -1 : id;
			var feeType = itemsMeter[i].getAttribute('FeeType');
			var feeName = itemsMeter[i].children[0].value;
			var fee = itemsMeter[i].children[1].value;
			var lowestQty = itemsMeter[i + 1].children[1].value;
			var currentQty = itemsMeter[i + 2].children[1].value;

			if (fee == '' || isNaN(fee)) {
				//console.log('请输入有效的金额')
				continue;
			}
			if (feeName != '' && itemMetersStr.indexOf('"' + feeName + '"') > 0) {
				mui.toast('仪表项名称 "' + feeName + ' "重复了，修改下名称吧');
				return false;
			}

			itemMetersStr += '{"ID":' + id + ',"FeeType":"' + feeType + '","FeeName":"' + feeName + '","MeterPrice":"' + fee + '","LowestConsume":"' + lowestQty + '","CurrMeterNum":"' + currentQty + '"},';
			i = i + 3;
		}
		itemsStr += itemMetersStr;
		if (itemsStr.length > 0)
			itemsStr = itemsStr.substr(0, itemsStr.length - 1)
			//var data = "[" + encodeURI(itemsStr) + "]";
		var data = "[" + itemsStr + "]";
		//ID=1001&RoomNumber=A101&....&FeeEntryList=[{json1},{json2},...]
		return data;
	},
	/**
	 *@description {获取租金项JSON}
	 */
	getRent: function() {
		var rentInput = document.getElementById("Rent");
		var rentFee = rentInput.value;
		var rentID = rentInput.getAttribute('FeeID');
		if (rentID == '' || rentID == null) {
			rentID = -1;
		}
		var rentJSON = '{"ID":"' + rentID + '","FeeType":"Rent","FeeName":"租金","Fee":"' + rentFee + '"}';
		return rentJSON;
	},
	/**
	 *@description {加载默认的固定收费项}
	 */
	loadDefaultFixedFees: function() {
		var fees = getJSONCache(default_fixedfees);
		//console.log(JSON.stringify(fees));
		if (fees) {
			var ul = document.querySelector('#fixeds>ul')
			ul.innerHTML = '';
			mui.each(fees, function(i, f) {
				if (f.FeeType == 'Normal') {
					var li = document.createElement('li');
					li.className = 'mui-table-view-cell';
					li.innerHTML = '<a onclick=\"wFeeItem.appendFixedRow(\'' + f.FeeName + '\',' + f.Fee + ')\">' + f.FeeName + ' ￥' + f.Fee + '</a>'
					ul.appendChild(li);
				}
			});
			var li = document.createElement('li');
			li.className = 'mui-table-view-cell';
			li.innerHTML = "<a onclick=\"wFeeItem.appendFixedRow('',0)\">自定义</a>";
			ul.appendChild(li);
		} else {
			wFeeItem.loadEmptyFixedFees();
		}
	},
	/**
	 *@description {加载默认的仪表收费项}
	 */
	loadDefaultMeterFees: function() {
		var fees = getJSONCache(default_meterfees);
		if (fees) {
			var ul = document.querySelector('#meters>ul');
			ul.innerHTML = '';
			mui.each(fees, function(i, f) {
				var li = document.createElement('li');
				li.className = 'mui-table-view-cell';
				li.innerHTML = '<a onclick=\"wFeeItem.appendMeterRow(\'' + f.FeeName + '\',\'' + f.FeeType + '\',\'吨\',' + f.MeterPrice + ',0,0,-2)\">' + f.FeeName + ' ￥' + f.MeterPrice + '</a>'
				ul.appendChild(li);
			});
			var li = document.createElement('li');
			li.className = 'mui-table-view-cell';
			li.innerHTML = "<a href='#metersCustom'>自定义</a>";
			ul.appendChild(li);
		} else {
			wFeeItem.loadEmptyMeterFees('#meters>ul');
		}
	},
	/**
	 *@description {加载空的固定收费项}
	 */
	loadEmptyFixedFees: function() {

		var ul = document.querySelector('#fixeds>ul')
		ul.innerHTML = '';

		var li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendFixedRow(\'管理费\',0)\">管理费 </a>";
		ul.appendChild(li);

		var li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendFixedRow(\'卫生费\',0)\">卫生费 </a>";
		ul.appendChild(li);

		li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendFixedRow(\'宽带费\',0)\">宽带费 </a>";
		ul.appendChild(li);

		li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendFixedRow(\'电视费\',0)\">电视费 </a>";
		ul.appendChild(li);

		var liCustom = document.createElement('li');
		liCustom.className = 'mui-table-view-cell';
		liCustom.innerHTML = "<a onclick=\"wFeeItem.appendFixedRow(\'\',0)\">自定义</a>";
		ul.appendChild(liCustom);
	},
	/**
	 *@description {加载空的仪表收费项}
	 *@param {seletor} ul选择器
	 */
	loadEmptyMeterFees: function(seletor) {

		var ul = document.querySelector(seletor)
		ul.innerHTML = '';

		var li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendMeterRow(\'水表\',\'water\',\'吨\',0,0,0,-1)\">水表 </a>";
		ul.appendChild(li);

		var li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendMeterRow(\'电表\',\'power\',\'度\',0,0,0,-1)\">电表 </a>";
		ul.appendChild(li);

		li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendMeterRow(\'燃气\',\'gas\',\'方\',0,0,0,-1)\">燃气 </a>";
		ul.appendChild(li);

		li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendMeterRow(\'热水\',\'hotwater\',\'吨\',0,0,0,-1)\">热水 </a>";
		ul.appendChild(li);
	},
	/**
	 *@description {加载空的仪表收费项}
	 */
	loadEmptyDepositFees: function() {

		var ul = document.querySelector('#deposits>ul')
		if (ul == null)
			return;

		ul.innerHTML = '';

		var li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendDepositRow(\'租金押金\',\'RentDeposit\')\">租金押金 </a>";
		ul.appendChild(li);

		li = document.createElement('li');
		li.className = 'mui-table-view-cell';
		li.innerHTML = "<a onclick=\"wFeeItem.appendDepositRow(\'\',\'Deposit\')\">自定义 </a>";
		ul.appendChild(li);
	},
	/**
	 *@description {设置只读}
	 */
	setReadOnly: function() {

		setItemsReadOnly('#liItemsFixed input');
		setItemsVisibility('#showAddFixed', 'none');
		setItemsVisibility('#showDelFixed', 'none');

		setItemsReadOnly('#liItemsDeposit input');
		setItemsVisibility('#showAddDeposit', 'none');
		setItemsVisibility('#showDelDeposit', 'none');

		setItemsReadOnly('#liItemsMeter input');
		setItemsVisibility('#showAddMeter', 'none');
		setItemsVisibility('#showDelMeter', 'none');
	},
	/**
	 *@description {清空收费项}
	 */
	clear: function() {

		var liFees = document.getElementById("liItemsFixed");
		if (liFees != null)
			liFees.innerHTML = '';
		liFees = document.getElementById("liItemsDeposit");
		if (liFees != null)
			liFees.innerHTML = '';
		liFees = document.getElementById("liItemsMeter");
		if (liFees != null)
			liFees.innerHTML = '';
	}
}