/**
 *@description {分享公用类}
 */
var wShare = {

	/**
	 * 分享的服务列表
	 */
	services: null,

	/**
	 * 分享服务类型
	 */
	service: 'weixin',

	/**
	 *会话
	 */
	session: 'WXSceneSession',

	/**
	 * 更新分享服务
	 */
	initSerivces: function() {

		plus.share.getServices(function(s) {
			wShare.services = {};
			for(var i in s) {
				var t = s[i];
				wShare.services[t.id] = t;
			}
		}, function(e) {
			mui.toast("获取分享服务列表失败：" + e.message);
		});
	},
	/**
	 * 分享操作
	 * @param {Object} msg
	 */
	share: function(msg) {

		var service = null;

		// 关闭弹出菜单
		//shareClose();
		//mui.toast("分享操作：");
		if(!wShare.service || !(service = wShare.services[wShare.service])) {
			mui.toast("无效的分享服务！");
			return;
		}
		if(service.authenticated) {
			//outSet("---已授权---");
			wShare.sendMessage(service, msg);
		} else {
			//outSet("---未授权---");
			service.authorize(function() {
				wShare.sendMessage(service, msg);
			}, function(e) {
				mui.toast("认证授权失败：" + e.code + " - " + e.message);
			});
		}
	},

	/**
	 * 发送分享消息
	 * @param {plus.share.ShareService} s
	 * @param {plus.share.ShareMessage} msg
	 * @param {Object} ex
	 */
	sendMessage: function(service, msg) {

		// 优先级顺序为：href>pictures>content。
		//		var msg = {
		//
		//			href: 'http://www.baidu.com', //链接
		//			title:'链接标题',
		//			pic:"http://pic.baidu.com/1.pgn", //图片
		//			content: sharecontent.value, 	  //文字
		//			extra: {
		//				scene: ex
		//			}
		//		};
		service.send(msg, function() {
			mui.toast("发送成功 ");
		}, function(e) {
			mui.toast("已取消发送 ");
		});
	},
	/**
	 * 发送链接消息
	 * @param {String} href
	 * @param {String} title
	 */
	getHrefMsg: function(title, href) {

		var msg = {
			href: href,
			title: title,
			extra: {
				scene: wShare.session
			}
		};

		return msg;
	},
	/**
	 * 发送文字消息
	 * @param {String} words
	 */
	getWordsMsg: function(words) {

		var msg = {
			content: words,
			extra: {
				scene: wShare.session
			}
		};
		return msg;
	},
	/**
	 * 发送图片消息
	 * @param {Array[ String ]} pictures
	 */
	getPictureMsg: function(pictures) {

		var msg = {
			pictures: pictures,
			extra: {
				scene: wShare.session
			}
		};
		return msg;
	},
	/**
	 * 解除所有分享服务的授权
	 */
	cancelAuth: function() {
		try {
			mui.toast("解除授权：");
			for(var i in wShare.services) {
				var service = wShare.services[i];
				if(service.authenticated) {
					mui.toast("取消\"" + service.description + "\"");
				}
				service.forbid();
			}
			// 取消授权后需要更新服务列表
			wShare.initSerivces();
			outLine("操作成功！");
		} catch(e) {
			wAlert(e);
		}
	},

	/**
	 * 打开分享
	 * @param {HTMLElement} popover 
	 */
	show: function(popover) {
		popover.style.display = "block";
		menu.style.display = "block";
		setTimeout(function() {
			popover.style.opacity = "1";
			menu.style.opacity = "1";
			menu.style.webkitTransform = "translateY(0)";
		}, 0);
	},
	/**
	 * 取消分享
	 * @param {HTMLElement} popover 
	 */
	hide: function(popover) {
		setTimeout(function() {
			popover.style.display = "none";
			menu.style.display = "none";
		}, 500);
		popover.style.opacity = "0";
		menu.style.opacity = "0";
		menu.style.webkitTransform = "translateY(100%)";
	},
	/**
	 * 关闭分享（无动画）
	 * @param {HTMLElement} popover 
	 */
	close: function(popover) {
		popover.style.display = "none";
		menu.style.display = "none";
		popover.style.opacity = "0";
		menu.style.opacity = "0";
		menu.style.webkitTransform = "translateY(100%)";
	}
}